@@ -3,15 +3,12 @@ package Digest::MD5;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '2.32';  # $Date: 2003/12/05 10:11:49 $
+$VERSION = '2.34';  # $Date: 2005/11/26 09:58:12 $
 
 require Exporter;
 *import = \&Exporter::import;
 @EXPORT_OK = qw(md5 md5_hex md5_base64);
 
-require DynaLoader;
-@ISA=qw(DynaLoader);
-
 eval {
     require Digest::base;
     push(@ISA, 'Digest::base');
@@ -23,7 +20,8 @@ if ($@) {
 
 
 eval {
-    Digest::MD5->bootstrap($VERSION);
+    require XSLoader;
+    XSLoader::load('Digest::MD5', $VERSION);
 };
 if ($@) {
     my $olderr = $@;
@@ -78,6 +76,13 @@ Inc. MD5 Message Digest algorithm from within Perl programs.  The
 algorithm takes as input a message of arbitrary length and produces as
 output a 128-bit "fingerprint" or "message digest" of the input.
 
+Note that the MD5 algorithm is not as strong as it used to be.  It has
+since 2005 been easy to generate different messages that produce the
+same MD5 digest.  It still seems hard to generate messages that
+produce a given digest, but it is probably wise to move to stronger
+algorithms for application depends on the digest to uniquely identify
+a message.
+
 The C<Digest::MD5> module provide a procedural interface for simple
 use, as well as an object oriented interface that can handle messages
 of arbitrary length and which can read files directly.
@@ -312,6 +317,11 @@ L<md5sum(1)>
 
 RFC 1321
 
+http://en.wikipedia.org/wiki/Md5
+
+The paper "How to Break MD5 and Other Hash Functions" by Xiaoyun Wang
+and Hongbo Yu.
+
 =head1 COPYRIGHT
 
 This library is free software; you can redistribute it and/or
